# setup.py
from distutils.core import setup

setup(name='scenterpy',
      version='0.4.5',
      author='mayne',
      author_email='dreama9ain@gmail.com',
      url='http://git.cognichain.com:8000/mayne/scenterpy.git',
      packages=['scenterpy', 'scenterpy.client', 'scenterpy.client.api'],
      )
